@@ -5,8 +5,8 @@ from json import JSONDecodeError
 
 import termcolor
 
-from duckietown_challenges import ChallengesConstants
 from . import dclogger
+from .challenges_constants import ChallengesConstants
 from .utils import indent
 
 
@@ -75,7 +75,7 @@ def make_server_request(
 
     server = get_duckietown_server_url()
     url = server + endpoint
-    dclogger.debug(url=url)
+    # dclogger.debug(url=url)
     headers = {}
     if token is not None:
         headers["X-Messaging-Token"] = token
@@ -176,9 +176,8 @@ def make_server_request(
                 p = prefix if i == 0 else p2
                 # l = termcolor.colored(l, 'blue')
                 s.append(termcolor.colored(p, attrs=["dark"]) + l)
-            from dt_shell.cli import dts_print
 
-            dts_print("\n".join(s))
+            print("\n".join(s))
 
     if result["ok"]:
         if "result" not in result:
